Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(47)

Unified Diff: webkit/tools/test_shell/test_shell.h

Issue 43058: Reverting 11396. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 11 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/tools/test_shell/mac/webwidget_host.mm ('k') | webkit/tools/test_shell/test_shell.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/tools/test_shell/test_shell.h
===================================================================
--- webkit/tools/test_shell/test_shell.h (revision 11408)
+++ webkit/tools/test_shell/test_shell.h (working copy)
@@ -209,9 +209,9 @@
// the flags set.
static void Dump(TestShell* shell);
// Writes the image captured from the given web view to the given file.
// The returned string is the ASCII-ized MD5 sum of the image.
- static std::string DumpImage(WebViewHost* web_view_host,
+ static std::string DumpImage(WebFrame* web_frame,
const std::wstring& file_name);
static void ResetWebPreferences();
« no previous file with comments | « webkit/tools/test_shell/mac/webwidget_host.mm ('k') | webkit/tools/test_shell/test_shell.cc » ('j') | no next file with comments »
@@ -209,9 +209,9 @@
// the flags set.
static void Dump(TestShell* shell);
- // Writes the image captured from the given web view to the given file.
+ // Writes the image captured from the given web frame to the given file.
// The returned string is the ASCII-ized MD5 sum of the image.

Powered by Google App Engine
This is Rietveld 408576698